@@ -31,7 +31,7 @@ public:
 	Graph();
 	virtual ~Graph();
 
-	void Init(Pp *pp0, int *gtype0, double *par, double *prepR, int *doDists, int *toroidal, int *dbg );
+	void Init(Pp *pp0, int *gtype0, double *par, double *prepR, int *doDists, double *preDists, int *toroidal, int *dbg );
 	void setNodelist(std::vector<std::vector<int> > *nodelist_new);
 	void addNew(int , int);
 	void sg_calc();
@@ -50,6 +50,7 @@ public:
 	void sg_RST();
 	void sg_RNG();
 	void sg_CCC();
+	void sg_STIR();
 
 	void sg_cut(double *R);
 	void sg_prune(double *lev);
@@ -59,4 +60,6 @@ public:
 	SEXP toSEXP();
 };
 
+double Attenuate(double r, double alpha); // used by STIR graph
+
 #endif /*GRAPH_H_*/
